@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,7 +27,7 @@ class AttachmentVcardFromAddressBookJobTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit AttachmentVcardFromAddressBookJobTest(QObject *parent = Q_NULLPTR);
+    explicit AttachmentVcardFromAddressBookJobTest(QObject *parent = nullptr);
     ~AttachmentVcardFromAddressBookJobTest();
 private Q_SLOTS:
     void testAttachmentVCardWithInvalidItem();
