@@ -98,20 +98,9 @@ static QStringList encodeIdn(const QStringList &emails)
 ComposerViewBase::ComposerViewBase(QObject *parent, QWidget *parentGui)
     : QObject(parent)
     , m_msg(KMime::Message::Ptr(new KMime::Message))
-    , m_attachmentController(nullptr)
-    , m_attachmentModel(nullptr)
-    , m_signatureController(nullptr)
-    , m_recipientsEditor(nullptr)
-    , m_identityCombo(nullptr)
-    , m_identMan(nullptr)
-    , m_editor(nullptr)
-    , m_transport(nullptr)
-    , m_dictionary(nullptr)
-    , m_fccCombo(nullptr)
     , m_parentWidget(parentGui)
     , m_cryptoMessageFormat(Kleo::AutoFormat)
     , m_autoSaveInterval(1 * 1000 * 60) // default of 1 min
-    , mSendLaterInfo(nullptr)
 {
     m_charsets << "utf-8"; // default, so we have a backup in case client code forgot to set.
 
@@ -143,6 +132,7 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
         m_recipientsEditor->setRecipientString(m_msg->to()->mailboxes(), MessageComposer::Recipient::To);
         m_recipientsEditor->setRecipientString(m_msg->cc()->mailboxes(), MessageComposer::Recipient::Cc);
         m_recipientsEditor->setRecipientString(m_msg->bcc()->mailboxes(), MessageComposer::Recipient::Bcc);
+        m_recipientsEditor->setRecipientString(m_msg->replyTo()->mailboxes(), MessageComposer::Recipient::ReplyTo);
         m_recipientsEditor->setFocusBottom();
 
         // If we are loading from a draft, load unexpanded aliases as well
@@ -170,6 +160,14 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
                 }
             }
         }
+        if (auto hrd = m_msg->headerByType("X-KMail-UnExpanded-Reply-To")) {
+            const QStringList spl = hrd->asUnicodeString().split(QLatin1Char(','));
+            for (const QString &addr : spl) {
+                if (!m_recipientsEditor->addRecipient(addr, MessageComposer::Recipient::ReplyTo)) {
+                    qCWarning(MESSAGECOMPOSER_LOG) << "Impossible to add recipient.";
+                }
+            }
+        }
     }
 
     // First, we copy the message and then parse it to the object tree parser.
@@ -400,6 +398,8 @@ void ComposerViewBase::readyForSending()
     job->setTo(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::To));
     job->setCc(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::Cc));
     job->setBcc(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::Bcc));
+    job->setReplyTo(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::ReplyTo));
+
     connect(job, &MessageComposer::EmailAddressResolveJob::result, this, &ComposerViewBase::slotEmailAddressResolved);
     job->start();
 }
@@ -420,12 +420,14 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
         mExpandedTo = resolveJob->expandedTo();
         mExpandedCc = resolveJob->expandedCc();
         mExpandedBcc = resolveJob->expandedBcc();
+        mExpandedReplyTo = resolveJob->expandedReplyTo();
         if (autoresizeImage) {
             QStringList listEmails;
             listEmails << mExpandedFrom;
             listEmails << mExpandedTo;
             listEmails << mExpandedCc;
             listEmails << mExpandedBcc;
+            listEmails << mExpandedReplyTo;
             MessageComposer::Utils resizeUtils;
             autoresizeImage = resizeUtils.filterRecipients(listEmails);
         }
@@ -442,12 +444,15 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
             case MessageComposer::Recipient::Bcc:
                 mExpandedBcc << r->email();
                 break;
+            case MessageComposer::Recipient::ReplyTo:
+                mExpandedReplyTo << r->email();
+                break;
             case MessageComposer::Recipient::Undefined:
-                Q_ASSERT(!"Unknown recpient type!");
+                Q_ASSERT(!"Unknown recipient type!");
                 break;
             }
         }
-        QStringList unExpandedTo, unExpandedCc, unExpandedBcc;
+        QStringList unExpandedTo, unExpandedCc, unExpandedBcc, unExpandedReplyTo;
         foreach (const QString &exp, resolveJob->expandedTo()) {
             if (!mExpandedTo.contains(exp)) {  // this address was expanded, so save it explicitly
                 unExpandedTo << exp;
@@ -463,6 +468,11 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
                 unExpandedBcc << exp;
             }
         }
+        foreach (const QString &exp, resolveJob->expandedReplyTo()) {
+            if (!mExpandedReplyTo.contains(exp)) {  // this address was expanded, so save it explicitly
+                unExpandedReplyTo << exp;
+            }
+        }
         auto header = new KMime::Headers::Generic("X-KMail-UnExpanded-To");
         header->from7BitString(unExpandedTo.join(QStringLiteral(", ")).toLatin1());
         m_msg->setHeader(header);
@@ -472,11 +482,14 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
         header = new KMime::Headers::Generic("X-KMail-UnExpanded-BCC");
         header->from7BitString(unExpandedBcc.join(QStringLiteral(", ")).toLatin1());
         m_msg->setHeader(header);
+        header = new KMime::Headers::Generic("X-KMail-UnExpanded-Reply-To");
+        header->from7BitString(unExpandedReplyTo.join(QStringLiteral(", ")).toLatin1());
+        m_msg->setHeader(header);
         autoresizeImage = false;
     }
 
     Q_ASSERT(m_composers.isEmpty()); //composers should be empty. The caller of this function
-    //checks for emptyness before calling it
+    //checks for emptiness before calling it
     //so just ensure it actually is empty
     //and document it
     // we first figure out if we need to create multiple messages with different crypto formats
@@ -785,6 +798,7 @@ void ComposerViewBase::fillGlobalPart(MessageComposer::GlobalPart *globalPart)
     globalPart->setParentWidgetForGui(m_parentWidget);
     globalPart->setCharsets(m_charsets);
     globalPart->setMDNRequested(m_mdnRequested);
+    globalPart->setRequestDeleveryConfirmation(m_requestDeleveryConfirmation);
 }
 
 void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, ComposerViewBase::RecipientExpansion expansion)
@@ -801,17 +815,18 @@ void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, Compose
     }
 
     infoPart->setTransportId(m_transport->currentTransportId());
-    infoPart->setReplyTo(replyTo());
     if (expansion == UseExpandedRecipients) {
         infoPart->setFrom(mExpandedFrom);
         infoPart->setTo(mExpandedTo);
         infoPart->setCc(mExpandedCc);
         infoPart->setBcc(mExpandedBcc);
+        infoPart->setReplyTo(mExpandedReplyTo);
     } else {
         infoPart->setFrom(from());
         infoPart->setTo(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::To));
         infoPart->setCc(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::Cc));
         infoPart->setBcc(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::Bcc));
+        infoPart->setReplyTo(m_recipientsEditor->recipientStringList(MessageComposer::Recipient::ReplyTo));
     }
     infoPart->setSubject(subject());
     infoPart->setUserAgent(QStringLiteral("KMail"));
@@ -844,6 +859,9 @@ void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, Compose
     if (auto hdr = m_msg->headerByType("X-KMail-UnExpanded-BCC")) {
         extras << hdr;
     }
+    if (auto hdr = m_msg->headerByType("X-KMail-UnExpanded-Reply-To")) {
+        extras << hdr;
+    }
     if (auto hdr = m_msg->organization(false)) {
         extras << hdr;
     }
@@ -1430,7 +1448,7 @@ QString ComposerViewBase::from() const
 
 QString ComposerViewBase::replyTo() const
 {
-    return MessageComposer::Util::cleanedUpHeaderString(m_replyTo);
+    return MessageComposer::Util::cleanedUpHeaderString(m_recipientsEditor->recipientString(MessageComposer::Recipient::ReplyTo));
 }
 
 QString ComposerViewBase::subject() const
@@ -1503,7 +1521,10 @@ void ComposerViewBase::updateRecipients(const KIdentityManagement::Identity &ide
     } else if (type == MessageComposer::Recipient::Cc) {
         oldIdentList = oldIdent.cc();
         newIdentList = ident.cc();
-    } else {
+    } else if (type == MessageComposer::Recipient::ReplyTo) {
+        oldIdentList = oldIdent.replyToAddr();
+        newIdentList = ident.replyToAddr();
+    }  else {
         return;
     }
 
@@ -1525,6 +1546,7 @@ void ComposerViewBase::identityChanged(const KIdentityManagement::Identity &iden
 {
     updateRecipients(ident, oldIdent, MessageComposer::Recipient::Bcc);
     updateRecipients(ident, oldIdent, MessageComposer::Recipient::Cc);
+    updateRecipients(ident, oldIdent, MessageComposer::Recipient::ReplyTo);
 
     KIdentityManagement::Signature oldSig = const_cast<KIdentityManagement::Identity &>
                                             (oldIdent).signature();
@@ -1589,7 +1611,7 @@ void ComposerViewBase::setFcc(const Akonadi::Collection &fccCollection)
 void ComposerViewBase::slotFccCollectionCheckResult(KJob *job)
 {
     if (job->error()) {
-        qCWarning(MESSAGECOMPOSER_LOG) << " void ComposerViewBase::slotFccCollectionCheckResult(KJob *job) errror " << job->errorString();
+        qCWarning(MESSAGECOMPOSER_LOG) << " void ComposerViewBase::slotFccCollectionCheckResult(KJob *job) error " << job->errorString();
         const Akonadi::Collection sentMailCol
             = Akonadi::SpecialMailCollections::self()->defaultCollection(Akonadi::SpecialMailCollections::SentMail);
         if (m_fccCombo) {
@@ -1615,11 +1637,6 @@ void ComposerViewBase::setFrom(const QString &from)
     m_from = from;
 }
 
-void ComposerViewBase::setReplyTo(const QString &replyTo)
-{
-    m_replyTo = replyTo;
-}
-
 void ComposerViewBase::setSubject(const QString &subject)
 {
     m_subject = subject;
@@ -2055,7 +2072,7 @@ void ComposerViewBase::addFollowupReminder(const QString &messageId)
             MessageComposer::FollowupReminderCreateJob *job = new MessageComposer::FollowupReminderCreateJob;
             job->setSubject(m_subject);
             job->setMessageId(messageId);
-            job->setTo(m_replyTo.isEmpty() ? mExpandedTo.join(QLatin1Char(',')) : m_replyTo);
+            job->setTo(mExpandedReplyTo.isEmpty() ? mExpandedTo.join(QLatin1Char(',')) : mExpandedReplyTo.join(QLatin1Char(',')));
             job->setFollowUpReminderDate(mFollowUpDate);
             job->setCollectionToDo(mFollowUpCollection);
             job->start();
@@ -2063,6 +2080,16 @@ void ComposerViewBase::addFollowupReminder(const QString &messageId)
     }
 }
 
+bool ComposerViewBase::requestDeleveryConfirmation() const
+{
+    return m_requestDeleveryConfirmation;
+}
+
+void ComposerViewBase::setRequestDeleveryConfirmation(bool requestDeleveryConfirmation)
+{
+    m_requestDeleveryConfirmation = requestDeleveryConfirmation;
+}
+
 KMime::Message::Ptr ComposerViewBase::msg() const
 {
     return m_msg;
