@@ -26,10 +26,6 @@ using namespace MessageComposer;
 
 MessageFactoryReplyJob::MessageFactoryReplyJob(QObject *parent)
     : QObject(parent)
-    , mMsg(nullptr)
-    , mOrigMsg(nullptr)
-    , mReplyAll(false)
-    , mIdentityManager(nullptr)
 {
 }
 
