@@ -23,23 +23,24 @@
 
 #include <QWidget>
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class KWindowPositioner : public QObject
 {
     Q_OBJECT
 public:
-    enum Mode { Right, Bottom };
+    enum Mode {
+        Right, Bottom
+    };
 
     KWindowPositioner(QWidget *master, QWidget *slave, Mode mode = Bottom);
 
     void reposition();
 
 private:
-    QWidget *mMaster;
-    QWidget *mSlave;
+    QWidget *mMaster = nullptr;
+    QWidget *mSlave = nullptr;
 
-    Mode mMode;
+    Mode mMode = Bottom;
 };
 }
 
