@@ -23,23 +23,20 @@
 #include "messagecomposer_export.h"
 
 #include <QObject>
-#include <QString>
-#include <QSet>
 
 #include <kmime/kmime_message.h>
 
 class KJob;
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class AkonadiSenderPrivate;
-class MESSAGECOMPOSER_EXPORT AkonadiSender: public QObject, public MessageSender
+class MESSAGECOMPOSER_EXPORT AkonadiSender : public QObject, public MessageSender
 {
     Q_OBJECT
 
 public:
-    explicit AkonadiSender(QObject *parent = Q_NULLPTR);
-    ~AkonadiSender();
+    explicit AkonadiSender(QObject *parent = nullptr);
+    ~AkonadiSender() override;
 
 protected:
     /**
@@ -53,13 +50,13 @@ protected:
 
     TODO cberzan: update docu...
     */
-    bool doSend(const KMime::Message::Ptr &msg, short sendNow) Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT bool doSend(const KMime::Message::Ptr &msg, short sendNow) override;
 
     /**
     Send queued messages, using the specified transport or the
     default, if none is given.
     */
-    bool doSendQueued(int transportId = -1) Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT bool doSendQueued(int transportId = -1) override;
 
 private:
     /**
