@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,8 +22,6 @@
 
 #include <klocalizedstring.h>
 #include <QApplication>
-#include <KAboutData>
-#include <KLocalizedString>
 #include <QCommandLineParser>
 #include "composer/composerlineedit.h"
 
@@ -32,15 +30,10 @@ using namespace MessageComposer;
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("testcomposerlineedit"), i18n("ComposerLineEdit"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("composerlineedit test app"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
     QWidget *w = new QWidget;
     QVBoxLayout *vbox = new QVBoxLayout(w);
 
@@ -57,4 +50,3 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
-
