@@ -1,10 +1,11 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
 
   KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   KMail is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,10 +25,8 @@
 
 class QMenu;
 
-namespace MessageList
-{
-namespace Util
-{
+namespace MessageList {
+namespace Util {
 QString messageSortingConfigName();
 QString messageSortDirectionConfigName();
 QString groupSortingConfigName();
@@ -43,4 +42,3 @@ void fillViewMenu(QMenu *menu, QObject *receiver);
 }
 
 #endif /* MESSAGELISTUTIL_H */
-
