@@ -33,11 +33,14 @@ class MessageList::Utils::ThemeConfigButtonPrivate
 {
 public:
     ThemeConfigButtonPrivate(ThemeConfigButton *owner)
-        : q(owner), mThemeComboBox(nullptr)  { }
+        : q(owner)
+        , mThemeComboBox(nullptr)
+    {
+    }
 
     ThemeConfigButton *const q;
 
-    const ThemeComboBox *mThemeComboBox;
+    const ThemeComboBox *mThemeComboBox = nullptr;
 
     void slotConfigureThemes();
 };
@@ -58,16 +61,19 @@ void ThemeConfigButtonPrivate::slotConfigureThemes()
 }
 
 ThemeConfigButton::ThemeConfigButton(QWidget *parent, const ThemeComboBox *themeComboBox)
-    : QPushButton(i18n("Configure..."), parent), d(new ThemeConfigButtonPrivate(this))
+    : QPushButton(i18n("Configure..."), parent)
+    , d(new ThemeConfigButtonPrivate(this))
 {
     d->mThemeComboBox = themeComboBox;
-    connect(this, SIGNAL(pressed()),
-            this, SLOT(slotConfigureThemes()));
+    connect(this, &ThemeConfigButton::pressed, this, [this]() {
+        d->slotConfigureThemes();
+    });
 
     //Keep theme combo up-to-date with any changes made in the configure dialog.
-    if (d->mThemeComboBox != nullptr)
-        connect(this, SIGNAL(configureDialogCompleted()),
-                d->mThemeComboBox, SLOT(slotLoadThemes()));
+    if (d->mThemeComboBox != nullptr) {
+        connect(this, &ThemeConfigButton::configureDialogCompleted,
+                d->mThemeComboBox, &ThemeComboBox::slotLoadThemes);
+    }
     setEnabled(Manager::instance());
 }
 
