@@ -7,8 +7,9 @@
     Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
     KMail is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,14 +44,6 @@ class MessageViewer::HeaderStylePrivate
 {
 public:
     HeaderStylePrivate()
-        : mStrategy(nullptr)
-        , mNodeHelper(nullptr)
-        , mSourceObject(nullptr)
-        , mPrinting(false)
-        , mTopLevel(true)
-        , mAllowAsync(false)
-        , mReadOnlyMessage(false)
-        , mShowEmoticons(true)
     {
     }
 
@@ -63,11 +56,11 @@ public:
     MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     QObject *mSourceObject = nullptr;
     Akonadi::MessageStatus mMessageStatus;
-    bool mPrinting;
-    bool mTopLevel;
-    bool mAllowAsync;
-    bool mReadOnlyMessage;
-    bool mShowEmoticons;
+    bool mPrinting = false;
+    bool mTopLevel = true;
+    bool mAllowAsync = false;
+    bool mReadOnlyMessage = false;
+    bool mShowEmoticons = true;
 };
 
 HeaderStyle::HeaderStyle()
