@@ -294,19 +294,21 @@ bool containsExternalReferences(const QString &str, const QString &extraHead)
 // this at all...
 QString processHtml(const QString &htmlSource, QString &extraHead)
 {
-    auto s = htmlSource.trimmed();
+    QString s = htmlSource.trimmed();
     s = s.replace(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
     s = s.replace(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
 
     // head
     s = s.replace(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive), QString()).trimmed();
-    if (s.startsWith(QLatin1String("<head>", Qt::CaseInsensitive))) {
-        const auto idx = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
-        if (idx < 0) {
+    const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
+    if (startIndex >= 0) {
+        const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
+
+        if (endIndex < 0) {
             return htmlSource;
         }
-        extraHead = s.mid(6, idx - 6);
-        s = s.mid(idx + 7).trimmed();
+        extraHead = s.mid(startIndex + 6, endIndex - startIndex - 6);
+        s = s.mid(endIndex + 7).trimmed();
     }
 
     // body
@@ -338,7 +340,7 @@ Interface::ObjectTreeSource *DefaultRendererPrivate::source() const
 
 void DefaultRendererPrivate::renderSubParts(const MessagePart::Ptr &msgPart, HtmlWriter *htmlWriter)
 {
-    foreach (const auto &m, msgPart->subParts()) {
+    for (const auto &m : msgPart->subParts()) {
         renderFactory(m, htmlWriter);
     }
 }
@@ -477,6 +479,7 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
     c.insert(QStringLiteral("block"), &block);
 
     block.setProperty("isPrinting", isPrinting());
+    block.setProperty("detailHeader", showEncryptionDetails());
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("isDecrypted", mp->decryptMessage());
     block.setProperty("isDecryptable", metaData.isDecryptable);
@@ -789,7 +792,7 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
 
     auto mode = mp->preferredMode();
     if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
-        foreach (const auto m, mp->availableModes()) {
+        for (const auto m : mp->availableModes()) {
             if (m != MimeTreeParser::Util::MultipartPlain) {
                 mode = m;
                 break;
@@ -1069,6 +1072,11 @@ bool DefaultRendererPrivate::showSignatureDetails() const
     return mShowSignatureDetails;
 }
 
+bool DefaultRendererPrivate::showEncryptionDetails() const
+{
+    return mShowEncryptionDetails;
+}
+
 int DefaultRendererPrivate::levelQuote() const
 {
     return mLevelQuote;
@@ -1109,6 +1117,11 @@ void DefaultRenderer::setShowExpandQuotesMark(bool showExpandQuotesMark)
     d->mShowExpandQuotesMark = showExpandQuotesMark;
 }
 
+void DefaultRenderer::setShowEncryptionDetails(bool showEncryptionDetails)
+{
+    d->mShowEncryptionDetails = showEncryptionDetails;
+}
+
 void DefaultRenderer::setShowSignatureDetails(bool showSignatureDetails)
 {
     d->mShowSignatureDetails = showSignatureDetails;
@@ -1131,13 +1144,11 @@ void DefaultRenderer::setCreateMessageHeader(std::function<QString(KMime::Messag
 
 QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QString indent)
 {
-    const QString line
+    QString ret
         = QStringLiteral("%1 * %3\n").arg(indent,
                                           QString::fromUtf8(messagePart->metaObject()->className()));
-    QString ret = line;
-
-    indent += QStringLiteral(" ");
-    foreach (const auto &subPart, messagePart->subParts()) {
+    indent += QLatin1Char(' ');
+    for (const auto &subPart : messagePart->subParts()) {
         ret += renderTreeHelper(subPart, indent);
     }
     return ret;
