@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -25,8 +25,7 @@
 #include <QVariant>
 #include "messageviewer_export.h"
 class QWebEnginePage;
-namespace MessageViewer
-{
+namespace MessageViewer {
 class ScamDetectionWebEnginePrivate;
 class MESSAGEVIEWER_EXPORT ScamDetectionWebEngine : public QObject
 {
