@@ -108,6 +108,7 @@ void Viewer::initialize()
     connect(d_ptr, &ViewerPrivate::moveMessageToTrash, this, &Viewer::moveMessageToTrash);
     connect(d_ptr, &ViewerPrivate::pageIsScrolledToBottom, this, &Viewer::pageIsScrolledToBottom);
     connect(d_ptr, &ViewerPrivate::printingFinished, this, &Viewer::printingFinished);
+    connect(d_ptr, &ViewerPrivate::zoomChanged, this, &Viewer::zoomChanged);
 
     setMessage(KMime::Message::Ptr(), MimeTreeParser::Delayed);
 }
@@ -286,10 +287,16 @@ void Viewer::setDisplayFormatMessageOverwrite(Viewer::DisplayFormatMessage forma
     d->setDisplayFormatMessageOverwrite(format);
 }
 
-void Viewer::setHtmlLoadExtOverride(bool override)
+void Viewer::setHtmlLoadExtDefault(bool loadExtDefault)
 {
     Q_D(Viewer);
-    d->setHtmlLoadExtOverride(override);
+    d->setHtmlLoadExtDefault(loadExtDefault);
+}
+
+void Viewer::setHtmlLoadExtOverride(bool loadExtOverride)
+{
+    Q_D(Viewer);
+    d->setHtmlLoadExtOverride(loadExtOverride);
 }
 
 bool Viewer::htmlLoadExtOverride() const
@@ -350,8 +357,7 @@ bool Viewer::event(QEvent *e)
 {
     Q_D(Viewer);
     if (e->type() == QEvent::PaletteChange) {
-        delete d->mCSSHelper;
-        d->mCSSHelper = new CSSHelper(d->mViewer);
+        d->recreateCssHelper();
         d->update(MimeTreeParser::Force);
         e->accept();
         return true;
@@ -687,4 +693,40 @@ void Viewer::setPrintElementBackground(bool printElementBackground)
     Q_D(Viewer);
     d->mViewer->setPrintElementBackground(printElementBackground);
 }
+
+bool Viewer::showSignatureDetails() const
+{
+    Q_D(const Viewer);
+    return d->showSignatureDetails();
+}
+
+void Viewer::setShowSignatureDetails(bool showDetails)
+{
+    Q_D(Viewer);
+    d->setShowSignatureDetails(showDetails);
+}
+
+bool Viewer::showEncryptionDetails() const
+{
+    Q_D(const Viewer);
+    return d->showEncryptionDetails();
+}
+
+void Viewer::setShowEncryptionDetails(bool showDetails)
+{
+    Q_D(Viewer);
+    d->setShowEncryptionDetails(showDetails);
+}
+
+qreal Viewer::webViewZoomFactor() const
+{
+    Q_D(const Viewer);
+    return d->webViewZoomFactor();
+}
+
+void Viewer::setWebViewZoomFactor(qreal factor)
+{
+    Q_D(Viewer);
+    d->setWebViewZoomFactor(factor);
+}
 }
