@@ -250,7 +250,7 @@ public:
 
     KMime::Message::Ptr message() const;
 
-    /** Returns whether the message should be decryted. */
+    /** Returns whether the message should be decrypted. */
     bool decryptMessage() const;
 
     /** Display a generic HTML splash page instead of a message. */
@@ -403,7 +403,9 @@ public:
     void setShowSignatureDetails(bool showDetails = true);
 
     /* show or hide encryption details */
-    void setHideEncryptionDetails(bool encDetails = true);
+    void setShowEncryptionDetails(bool showEncDetails);
+
+    bool showEncryptionDetails() const;
 
     void scrollToAttachment(KMime::Content *node);
     void setUseFixedFont(bool useFixedFont);
@@ -430,6 +432,9 @@ public:
     void checkPhishingUrl();
     void executeRunner(const QUrl &url);
     QUrl imageUrl() const;
+    Q_REQUIRED_RESULT qreal webViewZoomFactor() const;
+    void setWebViewZoomFactor(qreal factor);
+    void recreateCssHelper();
 
 private Q_SLOTS:
     void slotActivatePlugin(MessageViewer::ViewerPluginInterface *interface);
@@ -575,6 +580,7 @@ Q_SIGNALS:
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
     void printingFinished();
+    void zoomChanged(qreal zoomFactor);
 private:
     QString attachmentHtml() const;
 
@@ -588,8 +594,10 @@ private:
 
     void slotCheckedUrlFinished(const QUrl &url, WebEngineViewer::CheckPhishingUrlUtil::UrlStatus status);
 
-    MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     void slotDelayPrintPreview();
+    void applyZoomValue(qreal factor, bool saveConfig = true);
+    void slotZoomChanged(qreal zoom);
+    MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     bool mHtmlMailGlobalSetting;
     bool mHtmlLoadExternalDefaultSetting;
     bool mHtmlLoadExtOverride;
@@ -654,9 +662,10 @@ public:
     QPointer<WebEnginePartHtmlWriter> mPartHtmlWriter;
 
     int mLevelQuote;
-    bool mDecrytMessageOverwrite;
-    bool mShowSignatureDetails;
-    bool mForceEmoticons;
+    bool mDecrytMessageOverwrite = false;
+    bool mShowSignatureDetails = false;
+    bool mShowEncryptionDetails = false;
+    bool mForceEmoticons = true;
     int mRecursionCountForDisplayMessage;
     KMime::Content *mCurrentContent = nullptr;
     KMime::Content *mMessagePartNode = nullptr;
