@@ -64,10 +64,10 @@ public:
 
     void setPrintElementBackground(bool printElementBackground);
 
-    void executeHideShowEncryptionDetails(bool hide);
     void setLinkHovered(const QUrl &url);
     void setViewer(MessageViewer::ViewerPrivate *viewer);
     bool execPrintPreviewPage(QPrinter *printer, int timeout);
+    void readConfig();
 public Q_SLOTS:
     void slotZoomChanged(qreal zoom);
     void slotShowDetails();
