@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,15 +26,13 @@ class MessageViewer::ViewerPluginInterfacePrivate
 public:
     ViewerPluginInterfacePrivate()
     {
-
     }
 };
 
 ViewerPluginInterface::ViewerPluginInterface(QObject *parent)
-    : QObject(parent),
-      d(new MessageViewer::ViewerPluginInterfacePrivate)
+    : QObject(parent)
+    , d(new MessageViewer::ViewerPluginInterfacePrivate)
 {
-
 }
 
 ViewerPluginInterface::~ViewerPluginInterface()
@@ -77,6 +75,12 @@ void ViewerPluginInterface::setMessageItem(const Akonadi::Item &item)
     // Reimplement in subclass
 }
 
+void ViewerPluginInterface::setCurrentCollection(const Akonadi::Collection &col)
+{
+    Q_UNUSED(col);
+    // Reimplement in subclass
+}
+
 void ViewerPluginInterface::closePlugin()
 {
     // Reimplement in subclass
@@ -93,6 +97,12 @@ void ViewerPluginInterface::updateAction(const Akonadi::Item &item)
     // Reimplement in subclass
 }
 
+void ViewerPluginInterface::refreshActionList(KActionCollection *ac)
+{
+    //TODO
+    Q_UNUSED(ac);
+}
+
 void ViewerPluginInterface::addHelpTextAction(QAction *act, const QString &text)
 {
     act->setStatusTip(text);
