@@ -2,8 +2,9 @@
   Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -50,6 +51,8 @@ PrintingSettings::PrintingSettings(QWidget *parent)
             &PrintingSettings::changed);
     connect(d->mPrintingUi->printBackgroundColorAndImages, &QCheckBox::toggled, this,
             &PrintingSettings::changed);
+    connect(d->mPrintingUi->alwaysShowEncryptionSignatureDetail, &QCheckBox::toggled, this,
+            &PrintingSettings::changed);
 }
 
 PrintingSettings::~PrintingSettings()
@@ -65,6 +68,8 @@ void PrintingSettings::save()
                  MessageViewer::MessageViewerSettings::self()->respectExpandCollapseSettingsItem());
     saveCheckBox(d->mPrintingUi->printBackgroundColorAndImages,
                  MessageViewer::MessageViewerSettings::self()->printBackgroundColorImagesItem());
+    saveCheckBox(d->mPrintingUi->alwaysShowEncryptionSignatureDetail,
+                 MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetailsItem());
 }
 
 void PrintingSettings::doLoadFromGlobalSettings()
@@ -75,6 +80,8 @@ void PrintingSettings::doLoadFromGlobalSettings()
                MessageViewer::MessageViewerSettings::self()->respectExpandCollapseSettingsItem());
     loadWidget(d->mPrintingUi->printBackgroundColorAndImages,
                MessageViewer::MessageViewerSettings::self()->printBackgroundColorImagesItem());
+    loadWidget(d->mPrintingUi->alwaysShowEncryptionSignatureDetail,
+               MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetailsItem());
 }
 
 void PrintingSettings::doResetToDefaultsOther()
@@ -86,5 +93,7 @@ void PrintingSettings::doResetToDefaultsOther()
                MessageViewer::MessageViewerSettings::self()->respectExpandCollapseSettingsItem());
     loadWidget(d->mPrintingUi->printBackgroundColorAndImages,
                MessageViewer::MessageViewerSettings::self()->printBackgroundColorImagesItem());
+    loadWidget(d->mPrintingUi->alwaysShowEncryptionSignatureDetail,
+               MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetailsItem());
     MessageViewer::MessageViewerSettings::self()->useDefaults(bUseDefaults);
 }
