@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,8 +15,8 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef TEST_TEMPLATEPARSER_GUI_H
-#define TEST_TEMPLATEPARSER_GUI_H
+#ifndef TEST_TEMPLATEEDITOR_GUI_H
+#define TEST_TEMPLATEEDITOR_GUI_H
 
 #include <QWidget>
 
@@ -24,7 +24,7 @@ class TemplateEditorTestWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TemplateEditorTestWidget(QWidget *parent = Q_NULLPTR);
+    explicit TemplateEditorTestWidget(QWidget *parent = nullptr);
     ~TemplateEditorTestWidget();
 };
 
