@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,8 +29,6 @@ class WebEngineViewer::NetworkAccessManagerWebEnginePrivate
 {
 public:
     NetworkAccessManagerWebEnginePrivate()
-        : mManager(nullptr)
-        , mNetworkUrlInterceptor(nullptr)
     {
     }
 
@@ -62,6 +60,11 @@ void InterceptorManager::addInterceptor(WebEngineViewer::NetworkPluginUrlInterce
     d->mNetworkUrlInterceptor->addInterceptor(interceptor);
 }
 
+void InterceptorManager::removeInterceptor(WebEngineViewer::NetworkPluginUrlInterceptorInterface *interceptor)
+{
+    d->mNetworkUrlInterceptor->removeInterceptor(interceptor);
+}
+
 QList<QAction *> InterceptorManager::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const
 {
     QList<QAction *> actions;
