@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,8 +28,7 @@
 TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *vbox = new QVBoxLayout;
-    setLayout(vbox);
+    QVBoxLayout *vbox = new QVBoxLayout(this);
     QHBoxLayout *layout = new QHBoxLayout;
     vbox->addLayout(layout);
     pageView = new WebEngineViewer::WebEngineView(this);
@@ -46,7 +45,6 @@ TestDndWebEngine::TestDndWebEngine(QWidget *parent)
 
 TestDndWebEngine::~TestDndWebEngine()
 {
-
 }
 
 int main(int argc, char *argv[])
