@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,6 @@
 #include "networkurlinterceptormanager.h"
 #include "networkurlinterceptorpluginmanager.h"
 
-
 #include <WebEngineViewer/WebHitTestResult>
 
 using namespace WebEngineViewer;
@@ -63,10 +62,9 @@ void NetworkUrlInterceptorManagerPrivate::createInterfaces(QWebEngineView *webEn
 }
 
 NetworkUrlInterceptorManager::NetworkUrlInterceptorManager(QWebEngineView *webEngine, KActionCollection *ac, QObject *parent)
-    : QObject(parent),
-      d(new NetworkUrlInterceptorManagerPrivate(webEngine, ac, this))
+    : QObject(parent)
+    , d(new NetworkUrlInterceptorManagerPrivate(webEngine, ac, this))
 {
-
 }
 
 NetworkUrlInterceptorManager::~NetworkUrlInterceptorManager()
